# Copyright 2022 Webull
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# 	http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

class GRPCBaseRequest(object):

    def __init__(self, path, request=None, version='V1'):
        self._path = path
        self._request = request
        self._version = version

    def get_path(self):
        return self._path

    def serialize(self):
        if self._request:
            return self._request.SerializeToString()
        else:
            return None



# Copyright 2022 Webull
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# 	http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from webullsdkmdata.quotes.grpc.pb import quote_pb2
from webullsdkmdata.quotes.grpc.response import Response
from webullsdkmdata.request.grpc.get_instruments_request import GetInstrumentsRequest


class Instrument:
    def __init__(self, grpc_client):
        self.client = grpc_client

    def get_instrument(self, symbols, category):
        """
        Query the underlying information according to the security symbol list and security type.

        :param symbols: Securities symbol, such as: 00700,00981.
        :param category: Security type, enumeration.
        """
        request = GetInstrumentsRequest(symbols, category)
        result = self.client.get_response(request.get_path(), request.serialize())
        return Response(result, quote_pb2.InstrumentResponse())



# Copyright 2022 Webull
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# 	http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding=utf-8

from decimal import Decimal
from webullsdkmdata.quotes.subscribe.basic_result import BasicResult
from webullsdkmdata.quotes.subscribe.ask_bid_result import AskBidResult


class QuoteResult:
    def __init__(self, pb_quote):
        self.basic = BasicResult(pb_quote.basic)
        self.asks = []
        if pb_quote.asks:
            for ask in pb_quote.asks:
                self.asks.append(AskBidResult(ask))
        self.bids = []
        if pb_quote.bids:
            for bid in pb_quote.bids:
                self.bids.append(AskBidResult(bid))

    def get_basic(self):
        return self.basic

    def get_asks(self):
        return self.asks

    def get_bids(self):
        return self.bids

    def __repr__(self):
        return "basic: %s,asks: %s,bids:%s" % (self.basic, self.asks, self.bids)

    def __str__(self):
        return self.__repr__()



# Copyright 2022 Webull
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# 	http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding=utf-8

from webullsdkcore.common.easy_enum import EasyEnum
class Timespan(EasyEnum):
    M1 = (1, "1 minute")
    M5 = (2, "5 minute")
    M15 = (3, "15 minute")
    M30 = (4, "30 minute")
    M60 = (5, "60 minute")
    M120 = (6, "120 minute")
    M240 = (7, "240 minute")
    D = (8, "1 day")
    W = (9, "1 week")
    M = (10, "1 month")
    Y = (11, "1 year")